==> em_celery-0.1.19-py2.py3-none-any.whl: em_celery/tools/amz_uploadable_products_filter.py <==
# -*- coding: utf-8 -*-

import json

import click

from em_tasks.utils.offer_services import AmzOfferService
from em_tasks.utils.price_calculator import PriceCalculator
from em_tasks.utils.amz_uploadable_products_filter import AmzUploadableProductsFilter
from em_tasks.store.models import *

from em_celery import logger, init_db, get_config, get_amz_offer_filter_config, get_offer_service_config, get_product_service


@click.command('Filter Amazon uploadable product from Spapi.')
@click.option('-m', '--marketplace', required=True, type=str, default='us', help='Amazon marketplace.')
@click.option('-l', '--location_id', required=True, type=str, help='Location ID.')
@click.option('-o', '--output_path', required=True, type=str, help='Output file path')
def filter_products(output_path, location_id, marketplace='us'):
  init_db()

  output_path = os.path.abspath(os.path.expanduser(output_path))
  output_dir = os.path.dirname(output_path)
  if not os.path.isdir(output_dir):
    os.makedirs(output_dir)

  filter_cond = get_amz_offer_filter_config()
  offer_service_cfg = get_offer_service_config()
  offer_service = AmzOfferService(
    offer_service_cfg['host'], offer_service_cfg['port'],
    offer_service_cfg['user'], offer_service_cfg['password'], filter_cond)

  price_rules = {
    'roi': 0.3,
    'ad_cost': 4.5,
    'transfer_cost': 12
  }

  marketplace = marketplace.lower()
  cfg = get_config()
  price_rules_cfg = cfg.get('price.rules.amz_{}'.format(marketplace), dict())
  for k, v in price_rules_cfg.items():
    price_rules[k] = round(float(v), 2)
  price_calculator = PriceCalculator(price_rules)

  product_service = get_product_service()

  products_filter = AmzUploadableProductsFilter(marketplace, product_service, offer_service, price_calculator, output_path, location_id)
  products_filter.filter()


if __name__ == "__main__":
  filter_products()

==> em_celery-0.1.43-py2.py3-none-any.whl: em_celery/tools/amz_uploadable_products_filter.py <==
# -*- coding: utf-8 -*-

import json

import click

from em_tasks.utils.offer_services import AmzOfferService
from em_tasks.utils.price_calculator import PriceCalculator
from em_tasks.utils.amz_uploadable_products_filter import AmzUploadableProductsFilter
from em_tasks.store.models import *

from em_celery import logger, init_db, get_config, get_amz_offer_filter_config, get_offer_service_config, get_product_service


@click.command('Filter Amazon uploadable product from Spapi.')
@click.option('-s', '--store_code', required=True, type=str)
@click.option('-m', '--marketplace', required=True, type=str, default='us', help='Amazon marketplace.')
@click.option('-o', '--output_path', required=True, type=str, help='Output file path')
def filter_products(store_code, output_path, marketplace='us'):
  init_db()

  output_path = os.path.abspath(os.path.expanduser(output_path))
  output_dir = os.path.dirname(output_path)
  if not os.path.isdir(output_dir):
    os.makedirs(output_dir)

  filter_cond = get_amz_offer_filter_config()
  offer_service_cfg = get_offer_service_config()
  offer_service = AmzOfferService(
    offer_service_cfg['host'], offer_service_cfg['port'],
    offer_service_cfg['user'], offer_service_cfg['password'], filter_cond)

  price_rules = {
    'roi': 0.3,
    'ad_cost': 4.5,
    'transfer_cost': 12
  }

  marketplace = marketplace.lower()
  cfg = get_config()
  price_rules_cfg = cfg.get('price.rules.amz_{}'.format(marketplace), dict())
  for k, v in price_rules_cfg.items():
    price_rules[k] = round(float(v), 2)
  price_calculator = PriceCalculator(price_rules)

  product_service = get_product_service()

  products_filter = AmzUploadableProductsFilter(store_code, marketplace, product_service, offer_service, price_calculator, output_path)
  products_filter.filter()


if __name__ == "__main__":
  filter_products()
